# -*- coding: utf-8 -*-
# Copyright © 2021 Wacom. All rights reserved.
""""
Named Entity Linking
"""

__all__ = ['base', 'engine']

from knowledge.nel import base
from knowledge.nel import engine
